@@ -54,7 +54,7 @@ class WeChat:
     def send_msg(self, data):
         return self._send_msg(data)
 
-    def upload_media_get_media_id(self, filetype, filepath, filename):
+    def upload_media(self, filetype, filepath, filename):
         """
         上传临时素材到企微并获取media_id
         :param filetype: 图片（image）、语音（voice）、视频（video），普通文件（file）
